==> dokuwiki-2011.05.25a.tgz: dokuwiki/lib/plugins/usermanager/lang/de-informal/lang.php <==
<?php
/**
 * German (informal) language file
 *
 * @author Alexander Fischer <tbanus@os-forge.net>
 * @author Juergen Schwarzer <jschwarzer@freenet.de>
 * @author Marcel Metz <marcel_metz@gmx.de>
 * @author Matthias Schulte <post@lupo49.de>
 * @author Christian Wichmann <nospam@zone0.de>
 */
$lang['menu']                  = 'Benutzerverwalter';
$lang['noauth']                = '(Benutzeranmeldung ist nicht verfügbar)';
$lang['nosupport']             = '(Benutzerverwaltung wird nicht unterstützt)';
$lang['badauth']               = 'Ungültige Authentifizierung';
$lang['user_id']               = 'Benutzer';
$lang['user_pass']             = 'Passwort';
$lang['user_name']             = 'Echter Name';
$lang['user_mail']             = 'E-Mail';
$lang['user_groups']           = 'Gruppen';
$lang['field']                 = 'Feld';
$lang['value']                 = 'Wert';
$lang['add']                   = 'Zufügen';
$lang['delete']                = 'Löschen';
$lang['delete_selected']       = 'Lösche ausgewähltes';
$lang['edit']                  = 'Bearbeiten';
$lang['edit_prompt']           = 'Bearbeite diesen Benutzer';
$lang['modify']                = 'Änderungen speichern';
$lang['search']                = 'Suchen';
$lang['search_prompt']         = 'Suche ausführen';
$lang['clear']                 = 'Suchfilter zurücksetzen';
$lang['filter']                = 'Filter';
$lang['summary']               = 'Zeige Benutzer %1$d-%2$d von %3$d gefundenen. %4$d Benutzer insgesamt.';
$lang['nonefound']             = 'Keinen Benutzer gefunden. Insgesamt %d Benutzer.';
$lang['delete_ok']             = '%d Benutzer wurden gelöscht';
$lang['delete_fail']           = '%d konnte nicht gelöscht werden';
$lang['update_ok']             = 'Benutzer wurde erfolgreich aktualisiert';
$lang['update_fail']           = 'Aktualisierung des Benutzers ist fehlgeschlagen';
$lang['update_exists']         = 'Benutzername konnte nicht geändert werden, der angegebene Benutzername (%s) existiert bereits (alle anderen Änderungen werden angewandt).';
$lang['start']                 = 'Start';
$lang['prev']                  = 'vorige';
$lang['next']                  = 'nächste';
$lang['last']                  = 'letzte';
$lang['edit_usermissing']      = 'Der gewählte Benutzer wurde nicht gefunden. Der angegebene Benutzername könnte gelöscht oder an anderer Stelle geändert worden sein.';
$lang['user_notify']           = 'Benutzer benachrichtigen';
$lang['note_notify']           = 'Benachrichtigungsemails werden nur versandt, wenn der Benutzer ein neues Kennwort erhält.';
$lang['note_group']            = 'Neue Benutzer werden zur Standardgruppe (%s) hinzugefügt, wenn keine Gruppe angegeben wird.';
$lang['note_pass']             = 'Das Passwort wird automatisch erzeugt, wenn das Feld freigelassen wird und der Benutzer Benachrichtigungen aktiviert hat.';
$lang['add_ok']                = 'Benutzer erfolgreich hinzugefügt';
$lang['add_fail']              = 'Hinzufügen des Benutzers fehlgeschlagen';
$lang['notify_ok']             = 'Benachrichtigungsemail wurde versendet';
$lang['notify_fail']           = 'Benachrichtigungsemail konnte nicht gesendet werden';

==> dokuwiki-2012.10.13.tgz: dokuwiki/lib/plugins/usermanager/lang/de-informal/lang.php <==
<?php
/**
 * German (informal) language file
 *
 * @author Alexander Fischer <tbanus@os-forge.net>
 * @author Juergen Schwarzer <jschwarzer@freenet.de>
 * @author Marcel Metz <marcel_metz@gmx.de>
 * @author Matthias Schulte <dokuwiki@lupo49.de>
 * @author Christian Wichmann <nospam@zone0.de>
 * @author Pierre Corell <info@joomla-praxis.de>
 */
$lang['menu']                  = 'Benutzerverwaltung';
$lang['noauth']                = '(Benutzeranmeldung ist nicht verfügbar)';
$lang['nosupport']             = '(Benutzerverwaltung wird nicht unterstützt)';
$lang['badauth']               = 'Ungültige Authentifizierung';
$lang['user_id']               = 'Benutzer';
$lang['user_pass']             = 'Passwort';
$lang['user_name']             = 'Echter Name';
$lang['user_mail']             = 'E-Mail';
$lang['user_groups']           = 'Gruppen';
$lang['field']                 = 'Feld';
$lang['value']                 = 'Wert';
$lang['add']                   = 'Zufügen';
$lang['delete']                = 'Löschen';
$lang['delete_selected']       = 'Lösche Ausgewähltes';
$lang['edit']                  = 'Bearbeiten';
$lang['edit_prompt']           = 'Bearbeite diesen Benutzer';
$lang['modify']                = 'Änderungen speichern';
$lang['search']                = 'Suchen';
$lang['search_prompt']         = 'Suche ausführen';
$lang['clear']                 = 'Suchfilter zurücksetzen';
$lang['filter']                = 'Filter';
$lang['summary']               = 'Zeige Benutzer %1$d-%2$d von %3$d gefundenen. %4$d Benutzer insgesamt.';
$lang['nonefound']             = 'Keinen Benutzer gefunden. Insgesamt %d Benutzer.';
$lang['delete_ok']             = '%d Benutzer wurden gelöscht';
$lang['delete_fail']           = '%d konnte nicht gelöscht werden';
$lang['update_ok']             = 'Benutzer wurde erfolgreich aktualisiert';
$lang['update_fail']           = 'Aktualisierung des Benutzers ist fehlgeschlagen';
$lang['update_exists']         = 'Benutzername konnte nicht geändert werden, der angegebene Benutzername (%s) existiert bereits (alle anderen Änderungen werden angewandt).';
$lang['start']                 = 'Start';
$lang['prev']                  = 'vorige';
$lang['next']                  = 'nächste';
$lang['last']                  = 'letzte';
$lang['edit_usermissing']      = 'Der gewählte Benutzer wurde nicht gefunden. Der angegebene Benutzername könnte gelöscht oder an anderer Stelle geändert worden sein.';
$lang['user_notify']           = 'Benutzer benachrichtigen';
$lang['note_notify']           = 'Benachrichtigungsmails werden nur versandt, wenn der Benutzer ein neues Kennwort erhält.';
$lang['note_group']            = 'Neue Benutzer werden zur Standardgruppe (%s) hinzugefügt, wenn keine Gruppe angegeben wird.';
$lang['note_pass']             = 'Das Passwort wird automatisch erzeugt, wenn das Feld freigelassen wird und der Benutzer Benachrichtigungen aktiviert hat.';
$lang['add_ok']                = 'Benutzer erfolgreich hinzugefügt';
$lang['add_fail']              = 'Hinzufügen des Benutzers fehlgeschlagen';
$lang['notify_ok']             = 'Benachrichtigungsmail wurde versendet';
$lang['notify_fail']           = 'Benachrichtigungsemail konnte nicht gesendet werden';
